@@ -2,11 +2,11 @@ class Anagram(object):
     
     __author__ = 'Michael S. Russell'
     __email__ = 'michael.r2014@yahoo.co.uk'
-    __version__ = '1.0.4'
+    __version__ = '1.0.5'
     
     def __init__(self):
         
-        self.words = []
+        self.words = None
         self.real_words = []
         self.res = {}
         self.sentence = ""
@@ -17,7 +17,7 @@ class Anagram(object):
         with open("english.txt", "r") as r:
             words = r.read().replace("\n", ",").split(",")
             
-        self.words.append(words)
+        self.words = words
         
     
     def enter_words_print(self):
